#!/bin/bash

# Check for required arguments
if [ "$#" -ne 2 ]; then
    echo "Usage: $0 <RESTIC_PASSWORD> <ADDITIONAL_TAG>"
    exit 1
fi

# Assign arguments to variables
RESTIC_PASSWORD="$1"
ADDITIONAL_TAG="$2"

# Configuration
APP_PATH='/var/www/webroot/ROOT'
backupPath='/mnt/backups'
LOG_DIR="/home/jelastic/mb-backups/logs/manual/media"
LOG_FILE="${LOG_DIR}/backup_media_$(date +'%Y-%m-%d').log"
includePaths=("$APP_PATH/wp-content/uploads")

# Ensure log directory exists
mkdir -p "$LOG_DIR"

# Set Restic environment variables
export RESTIC_REPOSITORY="$backupPath"
export RESTIC_PASSWORD

# Logging start
echo "[$(date +'%Y-%m-%d %H:%M:%S')] Starting Media Backup" | tee -a "$LOG_FILE"

# Perform backup with additional tag
for path in "${includePaths[@]}"; do
    if restic backup "$path" --tag media_themes --tag "$ADDITIONAL_TAG"; then
        echo "[$(date +'%Y-%m-%d %H:%M:%S')] Backup completed successfully for $path with tags: media_themes, $ADDITIONAL_TAG." | tee -a "$LOG_FILE"
    else
        echo "[$(date +'%Y-%m-%d %H:%M:%S')] ERROR: Backup failed for $path." | tee -a "$LOG_FILE"
    fi
done

# Logging end
echo "[$(date +'%Y-%m-%d %H:%M:%S')] Media and Themes Backup process finished." | tee -a "$LOG_FILE"
